==> libunistring-0.9.tar.gz: libunistring-0.9/woe32dll/unistring-exports.c <==
/* List of exported symbols of libunistring on Cygwin.
   Copyright (C) 2006, 2009 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2006.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#include "woe32dll/export.h"

/* Variables declared in unictype.h */
VARIABLE(UC_CATEGORY_C)
VARIABLE(UC_CATEGORY_Cc)
VARIABLE(UC_CATEGORY_Cf)
VARIABLE(UC_CATEGORY_Cn)
VARIABLE(UC_CATEGORY_Co)
VARIABLE(UC_CATEGORY_Cs)
VARIABLE(UC_CATEGORY_L)
VARIABLE(UC_CATEGORY_Ll)
VARIABLE(UC_CATEGORY_Lm)
VARIABLE(UC_CATEGORY_Lo)
VARIABLE(UC_CATEGORY_Lt)
VARIABLE(UC_CATEGORY_Lu)
VARIABLE(UC_CATEGORY_M)
VARIABLE(UC_CATEGORY_Mc)
VARIABLE(UC_CATEGORY_Me)
VARIABLE(UC_CATEGORY_Mn)
VARIABLE(UC_CATEGORY_N)
VARIABLE(UC_CATEGORY_Nd)
VARIABLE(UC_CATEGORY_Nl)
VARIABLE(UC_CATEGORY_No)
VARIABLE(UC_CATEGORY_P)
VARIABLE(UC_CATEGORY_Pc)
VARIABLE(UC_CATEGORY_Pd)
VARIABLE(UC_CATEGORY_Pe)
VARIABLE(UC_CATEGORY_Pf)
VARIABLE(UC_CATEGORY_Pi)
VARIABLE(UC_CATEGORY_Po)
VARIABLE(UC_CATEGORY_Ps)
VARIABLE(UC_CATEGORY_S)
VARIABLE(UC_CATEGORY_Sc)
VARIABLE(UC_CATEGORY_Sk)
VARIABLE(UC_CATEGORY_Sm)
VARIABLE(UC_CATEGORY_So)
VARIABLE(UC_CATEGORY_Z)
VARIABLE(UC_CATEGORY_Zl)
VARIABLE(UC_CATEGORY_Zp)
VARIABLE(UC_CATEGORY_Zs)
VARIABLE(UC_PROPERTY_ALPHABETIC)
VARIABLE(UC_PROPERTY_ASCII_HEX_DIGIT)
VARIABLE(UC_PROPERTY_BIDI_ARABIC_DIGIT)
VARIABLE(UC_PROPERTY_BIDI_ARABIC_RIGHT_TO_LEFT)
VARIABLE(UC_PROPERTY_BIDI_BLOCK_SEPARATOR)
VARIABLE(UC_PROPERTY_BIDI_BOUNDARY_NEUTRAL)
VARIABLE(UC_PROPERTY_BIDI_COMMON_SEPARATOR)
VARIABLE(UC_PROPERTY_BIDI_CONTROL)
VARIABLE(UC_PROPERTY_BIDI_EMBEDDING_OR_OVERRIDE)
VARIABLE(UC_PROPERTY_BIDI_EUROPEAN_DIGIT)
VARIABLE(UC_PROPERTY_BIDI_EUR_NUM_SEPARATOR)
VARIABLE(UC_PROPERTY_BIDI_EUR_NUM_TERMINATOR)
VARIABLE(UC_PROPERTY_BIDI_HEBREW_RIGHT_TO_LEFT)
VARIABLE(UC_PROPERTY_BIDI_LEFT_TO_RIGHT)
VARIABLE(UC_PROPERTY_BIDI_NON_SPACING_MARK)
VARIABLE(UC_PROPERTY_BIDI_OTHER_NEUTRAL)
VARIABLE(UC_PROPERTY_BIDI_PDF)
VARIABLE(UC_PROPERTY_BIDI_SEGMENT_SEPARATOR)
VARIABLE(UC_PROPERTY_BIDI_WHITESPACE)
VARIABLE(UC_PROPERTY_COMBINING)
VARIABLE(UC_PROPERTY_COMPOSITE)
VARIABLE(UC_PROPERTY_CURRENCY_SYMBOL)
VARIABLE(UC_PROPERTY_DASH)
VARIABLE(UC_PROPERTY_DECIMAL_DIGIT)
VARIABLE(UC_PROPERTY_DEFAULT_IGNORABLE_CODE_POINT)
VARIABLE(UC_PROPERTY_DEPRECATED)
VARIABLE(UC_PROPERTY_DIACRITIC)
VARIABLE(UC_PROPERTY_EXTENDER)
VARIABLE(UC_PROPERTY_FORMAT_CONTROL)
VARIABLE(UC_PROPERTY_GRAPHEME_BASE)
VARIABLE(UC_PROPERTY_GRAPHEME_EXTEND)
VARIABLE(UC_PROPERTY_GRAPHEME_LINK)
VARIABLE(UC_PROPERTY_HEX_DIGIT)
VARIABLE(UC_PROPERTY_HYPHEN)
VARIABLE(UC_PROPERTY_IDEOGRAPHIC)
VARIABLE(UC_PROPERTY_IDS_BINARY_OPERATOR)
VARIABLE(UC_PROPERTY_IDS_TRINARY_OPERATOR)
VARIABLE(UC_PROPERTY_ID_CONTINUE)
VARIABLE(UC_PROPERTY_ID_START)
VARIABLE(UC_PROPERTY_IGNORABLE_CONTROL)
VARIABLE(UC_PROPERTY_ISO_CONTROL)
VARIABLE(UC_PROPERTY_JOIN_CONTROL)
VARIABLE(UC_PROPERTY_LEFT_OF_PAIR)
VARIABLE(UC_PROPERTY_LINE_SEPARATOR)
VARIABLE(UC_PROPERTY_LOGICAL_ORDER_EXCEPTION)
VARIABLE(UC_PROPERTY_LOWERCASE)
VARIABLE(UC_PROPERTY_MATH)
VARIABLE(UC_PROPERTY_NON_BREAK)
VARIABLE(UC_PROPERTY_NOT_A_CHARACTER)
VARIABLE(UC_PROPERTY_NUMERIC)
VARIABLE(UC_PROPERTY_OTHER_ALPHABETIC)
VARIABLE(UC_PROPERTY_OTHER_DEFAULT_IGNORABLE_CODE_POINT)
VARIABLE(UC_PROPERTY_OTHER_GRAPHEME_EXTEND)
VARIABLE(UC_PROPERTY_OTHER_ID_CONTINUE)
VARIABLE(UC_PROPERTY_OTHER_ID_START)
VARIABLE(UC_PROPERTY_OTHER_LOWERCASE)
VARIABLE(UC_PROPERTY_OTHER_MATH)
VARIABLE(UC_PROPERTY_OTHER_UPPERCASE)
VARIABLE(UC_PROPERTY_PAIRED_PUNCTUATION)
VARIABLE(UC_PROPERTY_PARAGRAPH_SEPARATOR)
VARIABLE(UC_PROPERTY_PATTERN_SYNTAX)
VARIABLE(UC_PROPERTY_PATTERN_WHITE_SPACE)
VARIABLE(UC_PROPERTY_PRIVATE_USE)
VARIABLE(UC_PROPERTY_PUNCTUATION)
VARIABLE(UC_PROPERTY_QUOTATION_MARK)
VARIABLE(UC_PROPERTY_RADICAL)
VARIABLE(UC_PROPERTY_SENTENCE_TERMINAL)
VARIABLE(UC_PROPERTY_SOFT_DOTTED)
VARIABLE(UC_PROPERTY_SPACE)
VARIABLE(UC_PROPERTY_TERMINAL_PUNCTUATION)
VARIABLE(UC_PROPERTY_TITLECASE)
VARIABLE(UC_PROPERTY_UNASSIGNED_CODE_VALUE)
VARIABLE(UC_PROPERTY_UNIFIED_IDEOGRAPH)
VARIABLE(UC_PROPERTY_UPPERCASE)
VARIABLE(UC_PROPERTY_VARIATION_SELECTOR)
VARIABLE(UC_PROPERTY_WHITE_SPACE)
VARIABLE(UC_PROPERTY_XID_CONTINUE)
VARIABLE(UC_PROPERTY_XID_START)
VARIABLE(UC_PROPERTY_ZERO_WIDTH)
/* Variables declared in uninorm.h */
VARIABLE(uninorm_nfc)
VARIABLE(uninorm_nfd)
VARIABLE(uninorm_nfkc)
VARIABLE(uninorm_nfkd)
/* Variables declared in unistring/version.h */
VARIABLE(_libunistring_version)

==> libunistring-1.0.tar.gz: libunistring-1.0/woe32dll/unistring-exports.c <==
/* List of exported symbols of libunistring on Cygwin.
   Copyright (C) 2006-2022 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2006.

   This program is free software: you can redistribute it and/or
   modify it under the terms of either:

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at your
       option) any later version.

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at your
       option) any later version.

   or both in parallel, as here.
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

#include "woe32dll/export.h"

/* Variables declared in unictype.h */
VARIABLE(UC_CATEGORY_C)
VARIABLE(UC_CATEGORY_Cc)
VARIABLE(UC_CATEGORY_Cf)
VARIABLE(UC_CATEGORY_Cn)
VARIABLE(UC_CATEGORY_Co)
VARIABLE(UC_CATEGORY_Cs)
VARIABLE(UC_CATEGORY_L)
VARIABLE(UC_CATEGORY_Ll)
VARIABLE(UC_CATEGORY_Lm)
VARIABLE(UC_CATEGORY_Lo)
VARIABLE(UC_CATEGORY_Lt)
VARIABLE(UC_CATEGORY_Lu)
VARIABLE(UC_CATEGORY_M)
VARIABLE(UC_CATEGORY_Mc)
VARIABLE(UC_CATEGORY_Me)
VARIABLE(UC_CATEGORY_Mn)
VARIABLE(UC_CATEGORY_N)
VARIABLE(UC_CATEGORY_Nd)
VARIABLE(UC_CATEGORY_Nl)
VARIABLE(UC_CATEGORY_No)
VARIABLE(UC_CATEGORY_P)
VARIABLE(UC_CATEGORY_Pc)
VARIABLE(UC_CATEGORY_Pd)
VARIABLE(UC_CATEGORY_Pe)
VARIABLE(UC_CATEGORY_Pf)
VARIABLE(UC_CATEGORY_Pi)
VARIABLE(UC_CATEGORY_Po)
VARIABLE(UC_CATEGORY_Ps)
VARIABLE(UC_CATEGORY_S)
VARIABLE(UC_CATEGORY_Sc)
VARIABLE(UC_CATEGORY_Sk)
VARIABLE(UC_CATEGORY_Sm)
VARIABLE(UC_CATEGORY_So)
VARIABLE(UC_CATEGORY_Z)
VARIABLE(UC_CATEGORY_Zl)
VARIABLE(UC_CATEGORY_Zp)
VARIABLE(UC_CATEGORY_Zs)
VARIABLE(UC_PROPERTY_ALPHABETIC)
VARIABLE(UC_PROPERTY_ASCII_HEX_DIGIT)
VARIABLE(UC_PROPERTY_BIDI_ARABIC_DIGIT)
VARIABLE(UC_PROPERTY_BIDI_ARABIC_RIGHT_TO_LEFT)
VARIABLE(UC_PROPERTY_BIDI_BLOCK_SEPARATOR)
VARIABLE(UC_PROPERTY_BIDI_BOUNDARY_NEUTRAL)
VARIABLE(UC_PROPERTY_BIDI_COMMON_SEPARATOR)
VARIABLE(UC_PROPERTY_BIDI_CONTROL)
VARIABLE(UC_PROPERTY_BIDI_EMBEDDING_OR_OVERRIDE)
VARIABLE(UC_PROPERTY_BIDI_EUROPEAN_DIGIT)
VARIABLE(UC_PROPERTY_BIDI_EUR_NUM_SEPARATOR)
VARIABLE(UC_PROPERTY_BIDI_EUR_NUM_TERMINATOR)
VARIABLE(UC_PROPERTY_BIDI_HEBREW_RIGHT_TO_LEFT)
VARIABLE(UC_PROPERTY_BIDI_LEFT_TO_RIGHT)
VARIABLE(UC_PROPERTY_BIDI_NON_SPACING_MARK)
VARIABLE(UC_PROPERTY_BIDI_OTHER_NEUTRAL)
VARIABLE(UC_PROPERTY_BIDI_PDF)
VARIABLE(UC_PROPERTY_BIDI_SEGMENT_SEPARATOR)
VARIABLE(UC_PROPERTY_BIDI_WHITESPACE)
VARIABLE(UC_PROPERTY_COMBINING)
VARIABLE(UC_PROPERTY_COMPOSITE)
VARIABLE(UC_PROPERTY_CURRENCY_SYMBOL)
VARIABLE(UC_PROPERTY_DASH)
VARIABLE(UC_PROPERTY_DECIMAL_DIGIT)
VARIABLE(UC_PROPERTY_DEFAULT_IGNORABLE_CODE_POINT)
VARIABLE(UC_PROPERTY_DEPRECATED)
VARIABLE(UC_PROPERTY_DIACRITIC)
VARIABLE(UC_PROPERTY_EMOJI)
VARIABLE(UC_PROPERTY_EMOJI_COMPONENT)
VARIABLE(UC_PROPERTY_EMOJI_MODIFIER)
VARIABLE(UC_PROPERTY_EMOJI_MODIFIER_BASE)
VARIABLE(UC_PROPERTY_EMOJI_PRESENTATION)
VARIABLE(UC_PROPERTY_EXTENDED_PICTOGRAPHIC)
VARIABLE(UC_PROPERTY_EXTENDER)
VARIABLE(UC_PROPERTY_FORMAT_CONTROL)
VARIABLE(UC_PROPERTY_GRAPHEME_BASE)
VARIABLE(UC_PROPERTY_GRAPHEME_EXTEND)
VARIABLE(UC_PROPERTY_GRAPHEME_LINK)
VARIABLE(UC_PROPERTY_HEX_DIGIT)
VARIABLE(UC_PROPERTY_HYPHEN)
VARIABLE(UC_PROPERTY_IDEOGRAPHIC)
VARIABLE(UC_PROPERTY_IDS_BINARY_OPERATOR)
VARIABLE(UC_PROPERTY_IDS_TRINARY_OPERATOR)
VARIABLE(UC_PROPERTY_ID_CONTINUE)
VARIABLE(UC_PROPERTY_ID_START)
VARIABLE(UC_PROPERTY_IGNORABLE_CONTROL)
VARIABLE(UC_PROPERTY_ISO_CONTROL)
VARIABLE(UC_PROPERTY_JOIN_CONTROL)
VARIABLE(UC_PROPERTY_LEFT_OF_PAIR)
VARIABLE(UC_PROPERTY_LINE_SEPARATOR)
VARIABLE(UC_PROPERTY_LOGICAL_ORDER_EXCEPTION)
VARIABLE(UC_PROPERTY_LOWERCASE)
VARIABLE(UC_PROPERTY_MATH)
VARIABLE(UC_PROPERTY_NON_BREAK)
VARIABLE(UC_PROPERTY_NOT_A_CHARACTER)
VARIABLE(UC_PROPERTY_NUMERIC)
VARIABLE(UC_PROPERTY_OTHER_ALPHABETIC)
VARIABLE(UC_PROPERTY_OTHER_DEFAULT_IGNORABLE_CODE_POINT)
VARIABLE(UC_PROPERTY_OTHER_GRAPHEME_EXTEND)
VARIABLE(UC_PROPERTY_OTHER_ID_CONTINUE)
VARIABLE(UC_PROPERTY_OTHER_ID_START)
VARIABLE(UC_PROPERTY_OTHER_LOWERCASE)
VARIABLE(UC_PROPERTY_OTHER_MATH)
VARIABLE(UC_PROPERTY_OTHER_UPPERCASE)
VARIABLE(UC_PROPERTY_PAIRED_PUNCTUATION)
VARIABLE(UC_PROPERTY_PARAGRAPH_SEPARATOR)
VARIABLE(UC_PROPERTY_PATTERN_SYNTAX)
VARIABLE(UC_PROPERTY_PATTERN_WHITE_SPACE)
VARIABLE(UC_PROPERTY_PRIVATE_USE)
VARIABLE(UC_PROPERTY_PUNCTUATION)
VARIABLE(UC_PROPERTY_QUOTATION_MARK)
VARIABLE(UC_PROPERTY_RADICAL)
VARIABLE(UC_PROPERTY_REGIONAL_INDICATOR)
VARIABLE(UC_PROPERTY_SENTENCE_TERMINAL)
VARIABLE(UC_PROPERTY_SOFT_DOTTED)
VARIABLE(UC_PROPERTY_SPACE)
VARIABLE(UC_PROPERTY_TERMINAL_PUNCTUATION)
VARIABLE(UC_PROPERTY_TITLECASE)
VARIABLE(UC_PROPERTY_UNASSIGNED_CODE_VALUE)
VARIABLE(UC_PROPERTY_UNIFIED_IDEOGRAPH)
VARIABLE(UC_PROPERTY_UPPERCASE)
VARIABLE(UC_PROPERTY_VARIATION_SELECTOR)
VARIABLE(UC_PROPERTY_WHITE_SPACE)
VARIABLE(UC_PROPERTY_XID_CONTINUE)
VARIABLE(UC_PROPERTY_XID_START)
VARIABLE(UC_PROPERTY_ZERO_WIDTH)
/* Variables declared in uninorm.h */
VARIABLE(uninorm_nfc)
VARIABLE(uninorm_nfd)
VARIABLE(uninorm_nfkc)
VARIABLE(uninorm_nfkd)
/* Variables declared in unicase.h */
VARIABLE(unicase_empty_prefix_context)
VARIABLE(unicase_empty_suffix_context)
/* Variables declared in unistring/version.h */
VARIABLE(_libunistring_version)
